﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Windows;
using System.IO;
using System.Reflection;

using BaseReaderPluginInterfaces;
using BaseReader.Managers;

namespace BaseReader
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        protected override void OnStartup(StartupEventArgs e)
        {
            this.Properties["Args"] = new String[] { };

            if (e.Args != null && e.Args.Count() > 0)
            {
                this.Properties["Args"] = e.Args;
            }
            base.OnStartup(e);

            String errors = String.Empty;
            Type baseType = typeof(IBaseReaderPlugin);

            String appFolder = Path.Combine(GetAppLocation, "Plugins");
            if (Directory.Exists(appFolder))
            {
                foreach (String file in Directory.GetFiles(appFolder, "*.dll"))
                {
                    try
                    {
                        Assembly assembly = Assembly.LoadFile(file);

                        foreach (Type expType in assembly.GetExportedTypes())
                        {
                            if (expType is IBaseReaderPlugin || baseType.IsAssignableFrom(expType))
                            {
                                IBaseReaderPlugin plugin = assembly.CreateInstance(expType.FullName) as IBaseReaderPlugin;
                                if (plugin == null)
                                    throw new Exception("Unable to load, instancing failed");

                                PluginManager.Add(plugin);
                            }
                        }
                    }
                    catch (Exception ex)
                    {
                        errors += Path.GetFileName(file) + ":\r\n" + ex.Message + "\r\n";
                    }
                }
                if (String.IsNullOrEmpty(errors) == false)
                    MessageBox.Show(errors, "Error while loading the following plugins");
            }
        }

        public static String GetAppLocation
        {
            get { return Path.GetDirectoryName(Assembly.GetEntryAssembly().Location); }
        }
    }
}
