﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using BaseReaderPluginInterfaces;
using System.Windows;
using System.IO;

namespace BaseReader.Managers
{
    public static class PluginManager
    {
        public static List<IBaseReaderPlugin> Plugins = new List<IBaseReaderPlugin>();

        public static void Add(IBaseReaderPlugin _Plugin)
        {
            if (_Plugin == null)
                throw new ArgumentNullException("_Plugin");
            Plugins.Add(_Plugin);
        }

        public static List<IBaseReaderPlugin> MatchPlugins(String _FilePath)
        {
            return Plugins.FindAll(p => p.IsExtensionSupported(_FilePath));
        }

        public static List<IBaseReaderItem> OpenFile(String _FilePath, out List<String> _Errors, List<IBaseReaderPlugin> _AllowedPlugins = null)
        {
            List<IBaseReaderItem> results = new List<IBaseReaderItem>();
            _Errors = new List<String>();

            bool found = false;
            foreach (IBaseReaderPlugin plugin in Plugins)
            {
                if ((_AllowedPlugins == null || _AllowedPlugins.Find(p => p == plugin) != null) &&
                    plugin.IsExtensionSupported(_FilePath))
                {
                    found = true;
                    try
                    {
                        IBaseReaderItem item = plugin.OpenFile(_FilePath);
                        item.FilePath = _FilePath;
                        item.Owner = plugin;

                        results.Add(item);
                    }
                    catch (Exception ex)
                    {
                        _Errors.Add("Plugin: " + plugin.Name + "\r\nFile: " + _FilePath + "\r\n\r\nError:\r\n" + ex.Message);
                    }
                }
            }
            if (found == false)
                _Errors.Add("There is no available plugin to read the following file:\r\n" + Path.GetFileName(_FilePath));

            return results;
        }
    }
}
