﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Win32;
using System.IO;
using System.Diagnostics;

namespace BaseReader.Tools
{
    public static class ToolIO
    {
        public static void OpenDirectory(String _DirectoryPath)
        {
            if (String.IsNullOrEmpty(_DirectoryPath) == true || Directory.Exists(_DirectoryPath) == false)
                throw new Exception("Unable to open folder: " + _DirectoryPath);

            Process.Start("explorer.exe", _DirectoryPath);
        }

        public static void OpenDirectoryAndSelectFile(String _FilePath)
        {
            if (String.IsNullOrEmpty(_FilePath) == true || File.Exists(_FilePath) == false)
                throw new Exception("Unable to find file: " + _FilePath);

            Process.Start("explorer.exe", "/select, \"" + _FilePath.Replace("/", "\\") + "\"");
        }

        public static String OpenFolderDialog(String _DefaultFolder)
        {
            OpenFileDialog dlg = new OpenFileDialog()
            {
                CheckFileExists = false,
                CheckPathExists = true,
                Multiselect = false,
                InitialDirectory = (String.IsNullOrEmpty(_DefaultFolder) == true || Directory.Exists(_DefaultFolder) == false ? String.Empty : _DefaultFolder),

                FileName = "(Get Folder)",
                Filter = "Folders only|*.FOLDER"
            };

            bool? result = dlg.ShowDialog();
            if (result.HasValue && result.Value == true)
            {
                if (dlg.FileName.EndsWith("(Get Folder).FOLDER", StringComparison.Ordinal))
                    return Path.GetDirectoryName(dlg.FileName);
                else if (dlg.FileName.EndsWith(".FOLDER", StringComparison.Ordinal))
                    return Path.Combine(Path.GetDirectoryName(dlg.FileName), Path.GetFileNameWithoutExtension(dlg.FileName));
            }
            return null;
        }
    }
}
