﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;

namespace BaseReader.View.Controls
{
    /// <summary>
    /// Interaction logic for ClosableTabItem.xaml
    /// </summary>
    public partial class ClosableTabItem : TabItem
    {
        public static readonly DependencyProperty TitleProperty =
            DependencyProperty.Register("Title", typeof(String), typeof(ClosableTabItem));
        public String Title
        {
            get { return GetValue(TitleProperty) as String; }
            set { SetValue(TitleProperty, value); }
        }

        public static readonly DependencyProperty IsModifiedProperty =
            DependencyProperty.Register("IsModified", typeof(bool), typeof(ClosableTabItem));
        public bool IsModified
        {
            get { return (bool)GetValue(IsModifiedProperty); }
            set { SetValue(IsModifiedProperty, value); }
        }

        public event CancelEventHandler OnClosing = null;
        public event Action<ClosableTabItem> Close = null;

        private object m_WheelDownSender = null;

        private bool m_HeaderGrabbed = false;
        public bool HeaderGrabbed
        {
            get { return m_HeaderGrabbed; }
            set { m_HeaderGrabbed = value; }
        }

        public ClosableTabItem()
        {
            Title = String.Empty;
            IsModified = false;
            InitializeComponent();
        }

        private void TryClose()
        {
            if (OnClosing != null)
            {
                CancelEventArgs args = new CancelEventArgs(false);
                OnClosing(this, args);
                if (args.Cancel == false && Close != null)
                    Close(this);
            }
        }

        private void CloseButton_Click(object sender, RoutedEventArgs e)
        {
            TryClose();
        }

        private void HeaderGrid_MouseDown(object sender, MouseButtonEventArgs e)
        {
            if (e.ChangedButton == MouseButton.Middle)
            {
                m_WheelDownSender = sender;
                e.Handled = true;
            }
            HeaderGrabbed = true;
        }

        private void HeaderGrid_PreviewMouseUp(object sender, MouseButtonEventArgs e)
        {
            // The sender is the same than the one who started the close process with wheel
            if (m_WheelDownSender == sender)
                TryClose();
            m_WheelDownSender = null;
            HeaderGrabbed = false;
        }
    }
}
