﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.ComponentModel;
using BaseReaderPluginInterfaces;

namespace BaseReader.View
{
    /// <summary>
    /// Interaction logic for PluginSelector.xaml
    /// </summary>
    public partial class PluginSelector : Window, INotifyPropertyChanged
    {
#region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyChange(String _PropertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(_PropertyName));
        }

#endregion
        
#region Fields

        public class SelectablePlugin : INotifyPropertyChanged
        {
#region INotifyPropertyChanged

            public event PropertyChangedEventHandler PropertyChanged;
            private void NotifyChange(String _PropertyName)
            {
                if (PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs(_PropertyName));
            }

#endregion

            private IBaseReaderPlugin m_Plugin = null;
            private bool m_IsSelected = true;

            public IBaseReaderPlugin Plugin
            {
                get { return m_Plugin; }
                set { m_Plugin = value; NotifyChange("Plugin"); }
            }
            public bool IsSelected
            {
                get { return m_IsSelected; }
                set { m_IsSelected = value; NotifyChange("IsSelected"); }
            }
        }

        private bool m_AllowSelection = false;
        private bool m_Validated = false;
        private String m_Description = "Plugin List";
        
#endregion

#region Properties

        public List<SelectablePlugin> ObservablePlugins { get; set; }

        public bool AllowSelection
        {
            get { return m_AllowSelection; }
            set { m_AllowSelection = value; NotifyChange("AllowSelection"); }
        }

        public bool Validated
        {
            get { return m_Validated; }
            set { m_Validated = value; NotifyChange("Validated"); }
        }

        public String Description
        {
            get { return m_Description; }
            set { m_Description = value; NotifyChange("Description"); }
        }

        public int SelectedPluginCount
        {
            get { return ObservablePlugins.Count(p => p.IsSelected); }
        }

#endregion

#region Methods
#region CDtors

        public PluginSelector()
        {
            InitializeComponent();
        }

#endregion

        public static List<IBaseReaderPlugin> ShowDialog(Window _Owner, List<IBaseReaderPlugin> _PluginList, String _Description, String _Caption = null, bool _AllowSelection = true)
        {
            PluginSelector ps = new PluginSelector();
            ps.Initialize(_PluginList);
            ps.AllowSelection = _AllowSelection;
            ps.Description = _Description;
            if (!String.IsNullOrEmpty(_Caption))
                ps.Title = _Caption;
            if (_Owner != null)
            {
                ps.Owner = _Owner;
                ps.WindowStartupLocation = WindowStartupLocation.CenterOwner;
            }
            ps.ShowDialog();

            if (ps.Validated)
                return ps.ObservablePlugins.FindAll(s => s.IsSelected).Select(s => s.Plugin).ToList();
            return _PluginList;
        }

        private void Initialize(List<IBaseReaderPlugin> _PluginList)
        {
            ObservablePlugins = new List<SelectablePlugin>();
            foreach (var plugin in _PluginList)
            {
                ObservablePlugins.Add(new SelectablePlugin()
                {
                    Plugin = plugin,
                    IsSelected = true
                });
            }
            NotifyChange("ObservablePlugins");
        }

        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        private void OkButton_Click(object sender, RoutedEventArgs e)
        {
            Validated = true;
            this.Close();
        }

#endregion

        private void CheckBox_Checked(object sender, RoutedEventArgs e)
        {
            NotifyChange("SelectedPluginCount");
        }

        private void CheckBox_Unchecked(object sender, RoutedEventArgs e)
        {
            NotifyChange("SelectedPluginCount");
        }
    }
}
