﻿// Copyright 2014 Yves Desgraupes
// This file is part of BaseReader.
// 
// BaseReader is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// BaseReader is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with BaseReader.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace BaseReaderPluginInterfaces
{
    public static class BaseReaderExtensions
    {
        public static bool IsExtensionSupported(this IBaseReaderPlugin _Plugin, String _FilePath)
        {
            String fileExt = Path.GetExtension(_FilePath);

            foreach (String ext in _Plugin.SupportedExtensions)
            {
                if (fileExt.Equals(ext, StringComparison.OrdinalIgnoreCase))
                    return true;
            }
            return false;
        }
    }

    public static class ByteExtensions
    {
        public static UInt16 SwapU16(this UInt16 _Val)
        {
            return (UInt16)((_Val >> 8 & 0x00FF) | (_Val << 8 & 0xFF00));
        }

        public static UInt32 SwapU32(this UInt32 _Val)
        {
            return (UInt32)(((((UInt16)_Val).SwapU16() & 0xffff) << 0x10) | (((UInt16)(_Val >> 0x10)).SwapU16() & 0xffff));
        }

        public static float SwapFloat(this float _Val)
        {
            Byte[] tab = BitConverter.GetBytes(_Val);
            Array.Reverse(tab);
            return (BitConverter.ToSingle(tab, 0));
        }
    }
}
